==> seedsui-react-5.5.91.tgz: package/lib/ContainerPull/BottomError.js <==
var _excluded = ["children"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { forwardRef, useRef, useImperativeHandle, useContext } from 'react';
import Context from "./../Context/instance.js";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var BottomError = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var children = _ref.children,
      others = _objectWithoutProperties(_ref, _excluded);

  // context
  var context = useContext(Context) || {};

  var locale = context.locale || function (remark) {
    return remark || '';
  };

  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    return rootRef.current;
  });
  return /*#__PURE__*/_jsxs("div", _objectSpread(_objectSpread({
    ref: rootRef,
    className: "SID-Dragrefresh-ErrorContainer containerpull-pull",
    style: {
      height: '50px'
    }
  }, others), {}, {
    children: [!children && /*#__PURE__*/_jsx("div", {
      className: "containerpull-pull-box",
      children: /*#__PURE__*/_jsx("div", {
        className: "containerpull-pull-caption",
        children: locale('加载失败, 请稍后再试', 'refreshing_failed')
      })
    }), children]
  }));
});
export default BottomError;

==> seedsui-react-5.5.92.tgz: package/lib/ContainerPull/BottomError.js <==
var _excluded = ["children"];

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { forwardRef, useRef, useImperativeHandle, useContext } from 'react';
import Context from "./../Context/instance.js";
var BottomError = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var children = _ref.children,
      others = _objectWithoutProperties(_ref, _excluded);

  // context
  var context = useContext(Context) || {};

  var locale = context.locale || function (remark) {
    return remark || '';
  };

  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    return rootRef.current;
  });
  return /*#__PURE__*/React.createElement("div", _extends({
    ref: rootRef,
    className: "SID-Dragrefresh-ErrorContainer containerpull-pull",
    style: {
      height: '50px'
    }
  }, others), !children && /*#__PURE__*/React.createElement("div", {
    className: "containerpull-pull-box"
  }, /*#__PURE__*/React.createElement("div", {
    className: "containerpull-pull-caption"
  }, locale('加载失败, 请稍后再试', 'refreshing_failed'))), children);
});
export default BottomError;
